<?php

namespace Modules\Menupdf\Database\Seeds;

use App\Models\Company;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Seeder;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use App\Models\User;

class MenupdfDatabaseSeeder extends Seeder
{
    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        //if project is not in demo mode, don't insert demo data
        if(!config('settings.is_demo')){
            return;
        }

        Model::unguard();

        DB::table('plan')->insert([
            'name' => 'Free',
            'limit_items'=>0,
            'limit_orders'=>0,
            'price'=>0,
            'paddle_id'=>'',
            'description'=>'Test drive our platform',
            'features'=>'QR Menu creation, Multiple menus, Project branding displayed, Analytics',
            'created_at' => now(),
            'updated_at' => now(),
            'enable_ordering'=>2,
        ]);

        DB::table('plan')->insert([
            'name' => 'Standard',
            'limit_items'=>0,
            'limit_orders'=>0,
            'price'=>25,
            'paddle_id'=>'',
            'period'=>1,
            'description'=>'30 days trial',
            'features'=>'QR Menu creation, Multiple menus, Project branding removed, Call waiter, Analytics',
            'created_at' => now(),
            'updated_at' => now(),
            'enable_ordering'=>1,
        ]);

        DB::table('plan')->insert([
            'name' => 'Pro',
            'limit_items'=>0,
            'limit_orders'=>0,
            'price'=>25,
            'paddle_id'=>'',
            'period'=>1,
            'description'=>'30 days trial',
            'features'=>'QR Menu creation, Multiple menus, Project branding removed, Call waiter, Expenses tracking, Staff members, Analytics',
            'created_at' => now(),
            'updated_at' => now(),
            'enable_ordering'=>1,
        ]);

        //Company owner s
        $demoOwnerId=DB::table('users')->insertGetId([
            'name' => 'Demo owner',
            'email' =>  'owner@example.com',
            'password' => Hash::make('secret'),
            'email_verified_at' => now(),
            'created_at' => now(),
            'updated_at' => now(),
            'plan_id'=> 2,
        ]);

        //Assign owner role
        $demoOwner=User::find($demoOwnerId);
        $demoOwner->assignRole('owner');

        // Pizza Company
        $lastCompanyId=DB::table('companies')->insertGetId([
            'name'=>'Jusico',
            'is_featured'=>1,
            'active'=>1,
            'logo'=>'https://saasscripts.net/demo_files/img/juicelogo.jpeg',
            'cover'=>'https://saasscripts.net/demo_files/img/juice.png',
            'subdomain'=>'jusicomk', // strtolower(preg_replace('/[^A-Za-z0-9]/', '', $company['name'])),
            'user_id'=>$demoOwnerId,
            'created_at' => now(),
            'updated_at' => now(),
            'address' => 'Dimce Mircev 1, Negotino, Macedonia',
            'phone' => '+389 75 728 000',
            'whatsapp_phone' => '+38971605048',
            'description'=>'Fresh Juices, Smoothies, Chia, and Best Coffee',
            'minimum'=>10
        ]);

        $vendor=Company::find($lastCompanyId);
        $vendor->setConfig('facebook','https://www.facebook.com/jusicomk/');
        $vendor->setConfig('instagram','https://www.instagram.com/jusico.mk/');
        $vendor->setConfig('impressum_title','WiFi Access');
        $vendor->setConfig('impressum_value','Wifi access is available for all our guests. The password is I+LOVE+SMOOTHIE.');

        $documents = [
            ['image'=>'https://saasscripts.net/demo_files/img/jusico/smoothie.png','title'=>'{"en":"Smoothies + Chia + Coffee Menu"}','link'=>'https://saasscripts.net/demo_files/TVMenu.pdf', 'description'=>'{"en":"Explore our always fresh smoothies, chia, and special coffees."}'],
            ['image'=>'https://saasscripts.net/demo_files/img/jusico/salad.png','title'=>'{"en":"Salads menu"}','link'=>'https://saasscripts.net/demo_files/Salads.pdf', 'description'=>'{"en":"We prepare our salads with fresh ingredients."}'],
            ['image'=>'https://saasscripts.net/demo_files/img/jusico/sandw.png','title'=>'{"en":"Sandwiches menu"}','link'=>'https://saasscripts.net/demo_files/Sandwich.pdf', 'description'=>'{"en":"Are you ut to for a cold sandwich"}'],
        ];
        foreach ($documents as $key => $document) {
            DB::table('posts')->insert([
                'post_type' => 'menudocument',
                'vendor_id' => $lastCompanyId,
                'title' => $document['title'],
                'image' => $document['image'],
                'description' => $document['description'],
                'link'=>$document['link'],
                'created_at' => now(),
                'updated_at' => now(),
            ]);
        }


        //Demo content for the landing page
        $faq = [
            [
                'type' => 'faq',
                'title' => '{"en":"What is a QR menu, and how does it work?"}',
                'description' => '{"en":"A QR menu is a digital menu that customers can access by scanning a QR code with their phone camera. Our SaaS company provides restaurants with the tools to create their own QR menu, which can be customized to include menu items, pricing, descriptions, and photos."}',
            ],
            [
                'type' => 'faq',
                'title' => '{"en":"How secure is the QR menu? Can customers\' personal information be compromised?"}',
                'description' => '{"en":"Our QR menu is designed to be secure and protect customers\' personal information. The menu is hosted on our secure servers, and we use encryption to protect all data transmitted between the customer\'s phone and the server. We do not collect any personal information from customers, such as their name or email address, when they scan the QR code to view the menu."}',
            ],
            [
                'type' => 'faq',
                'title' => '{"en":"Can restaurants update the QR menu in real-time?"}',
                'description' => '{"en":"Yes, our SaaS platform allows restaurants to update their QR menu in real-time. This means that if there are changes to the menu, such as the addition of new items or a price increase, the restaurant can easily update the menu on our platform, and the changes will be reflected in the QR code. This ensures that customers always have access to the most up-to-date menu."}',
            ],
            [
                'type' => 'faq',
                'title' => '{"en":"How does a restaurant create a QR menu using your platform?"}',
                'description' => '{"en":"Creating a QR menu with our platform is easy and straightforward. Restaurants can sign up for an account on our website and follow the step-by-step instructions to create their QR menu. They can customize the menu with their restaurant\'s branding, including logos and colors, and add menu items, pricing, descriptions, and photos. Once the menu is complete, they can generate a unique QR code that can be printed and placed on tables, or displayed on a digital screen, for customers to scan and view the menu."}',
            ],
        ];

        $testimonials = [
            [
                'type' => 'testimonial',
                'title' => '{"en":"John Smith"}',
                'description' => '{"en":"This QR menu has completely transformed the dining experience for my customers. They love being able to view the menu on their phones without touching a physical menu. The platform is easy to use and the support team is quick to respond. Highly recommend!"}',
                'image' => 'https://randomuser.me/api/portraits/men/62.jpg',
            ],
            [
                'type' => 'testimonial',
                'title' => '{"en":"Jane Doe"}',
                'description' => '{"en":"The QR menu has reduced paper waste and streamlined the ordering process. The platform is user-friendly and the ability to update the menu in real-time is helpful. Highly recommend!"}',
                'image' => 'https://randomuser.me/api/portraits/women/32.jpg',
            ],
            [
                'type' => 'testimonial',
                'title' => '{"en":"Bob Johnson"}',
                'description' => '{"en":"This QR menu has been overwhelmingly positive. Customers appreciate the convenience and safety of viewing the menu on their phones. The platform is easy to use and customer support is excellent. Highly satisfied and recommend!"}',
                'image' => 'https://randomuser.me/api/portraits/men/61.jpg',
            ],
        ];


        $features = [
            [
                'type' => 'feature',
                'title' => '{"en":"Easy Online Menu via PDFs"}',
                'description' => '{"en":"Easily create an online menu by uploading PDF files of your restaurant\'s menu. Our platform will convert the PDF into a user-friendly digital menu that customers can view on their phones or other devices."}',
                'image' => 'https://saasscripts.net/demo_files/easy-online-menu.jpeg',
            ],
            [
                'type' => 'feature',
                'title' => '{"en":"Call Waiter and Call Bill"}',
                'description' => '{"en":"Allow your customers to easily call their waiter or request the bill from their phone with our call waiter and call bill features. This feature reduces wait times and enhances the overall dining experience for your customers."}',
                'image' => 'https://saasscripts.net/demo_files/call-waiter-call-bill.jpeg',
            ],
            [
                'type' => 'feature',
                'title' => '{"en":"Real-time Menu Updates"}',
                'description' => '{"en":"Easily update your menu in real-time to reflect changes to your offerings, such as new menu items or price updates. Our platform allows you to make changes quickly and easily, and the updated menu will be reflected in the QR code."}',
                'image' => 'https://saasscripts.net/demo_files/real-time-menu-updates.jpeg',
            ],
            [
                'type' => 'feature',
                'title' => '{"en":"Social Networks"}',
                'description' => '{"en":"Include links to your restaurant\'s social media profiles in the QR menu to encourage customers to follow and engage with your business on social media. This feature helps to build brand awareness and customer loyalty."}',
                'image' => 'https://saasscripts.net/demo_files/links-to-social-networks.jpeg',
            ],
        ];
        
        

        $content = array_merge($faq, $testimonials,$features);
        
        

        foreach ($content as $key => $element) {
            DB::table('posts')->insert([
                'post_type' => $element['type'],
                'title' => $element['title'],
                'image' => isset($element['image'])?$element['image']:null,
                'description' => $element['description'],
                'link'=>isset($element['link'])?$element['link']:null,
                'created_at' => now(),
                'updated_at' => now(),
            ]);
        }
        


        Model::reguard();
    }
}
