<?php

namespace Modules\Menupdf\Http\Controllers;

use App\Models\Posts;
use App\Http\Controllers\Controller;
use Illuminate\Http\Request;

class MenudocumentsController extends Controller
{
    protected $imagePath = 'uploads/companies/';
    protected $type = 'menudocument';
    protected $title="";
    protected $itemName="";
    protected $indexRoute='menudocuments.index';
    protected $editRoute='menudocuments.edit';
    protected $deleteRoute='menudocuments.delete';
    protected $createRoute='menudocuments.create';
    protected $storeRoute='menudocuments.store';
    protected $updateRoute='menudocuments.update';

     public function __construct() {
        $this->title=__('Documents');
        $this->itemName=__('Document');
    }
    
     /**
     * Get Fields
     */
    protected function getFields(Posts $post=null)
    {
        $dataToReturn=[];
        array_push($dataToReturn,['ftype'=>'image', 'name'=>__('Image'), 'id'=>'image']);
        array_push($dataToReturn,['ftype'=>'input', 'name'=>'Title', 'id'=>'title', 'placeholder'=>__('Enter title'), 'required'=>true]);
        array_push($dataToReturn,['ftype'=>'input', 'name'=>'Description', 'id'=>'description', 'placeholder'=>__('Enter description'), 'required'=>true]);
        array_push($dataToReturn,['ftype'=>'input','type'=>'hidden', 'name'=>'Type', 'id'=>'type', 'placeholder'=>__('Enter type'), 'required'=>true,'value'=>$this->type]);
        array_push($dataToReturn,['ftype'=>'input', 'type'=>'file', 'name'=>'PDF', 'id'=>'file', 'placeholder'=>__('Upload your menu'), 'required'=>false]);

        if($post){
            $dataToReturn[0]['value']=strlen($post->image)>3?$post->image_link:null;
            $dataToReturn[1]['value']=$post->title;
            $dataToReturn[2]['value']=$post->description;
            $dataToReturn[3]['value']=$post->type;
        }


        return $dataToReturn;
    }

    public function getCreateRules(){
        $rules=[
            'title' => ['required', 'string', 'max:255'],
        ];
        return $rules;
    }

    public function validateAccess()
    {
        if (!auth()->user()->hasRole(['admin','owner','staff'])) {
            abort(404);
        }
    }

    public function index()
    {
        $this->validateAccess();
        return view('crud.posts.index', ['setup' => [
            'iscontent' => true,
            'title' => $this->title,
            'action_link' => route($this->createRoute,['type'=>$this->type]),
            'edit_link' => $this->editRoute,
            'delete_link'=>$this->deleteRoute,
            'action_name' => __('Add new'),
            'items' => Posts::where('post_type', $this->type)->where('vendor_id',$this->getCompany()->id)->get(),
            'item_names' => $this->title,
            'breadcrumbs' => [
                [$this->title, route($this->indexRoute,['type'=>$this->type])],
            ],
        ]]);
    }


    public function create()
    {
        $this->validateAccess();
        return view('general.form', ['setup' => [
                'title'=>__('crud.add_new_item', ['item'=>__($this->itemName)]),
                'action_link' => route($this->indexRoute),
                'action_name' => __('Back'),
                'iscontent' => true,
                'action' => route($this->storeRoute),
                'breadcrumbs' => [
                    [$this->title, route($this->indexRoute)],
                    [__('New'), null],
                ],
            ],
            'fields'=>$this->getFields(null)
        ]);
    }

    public function store(Request $request)
    {
        $this->validateAccess();
        //Validate first
        $request->validate($this->getCreateRules());

        $post = Posts::create([
            'post_type' => $this->type,
            'title' => $request->title,
            'description' => $request->description,
            'image'=>'',
            'vendor_id'=>$this->getCompany()->id
        ]);

        $post->save();

        if ($request->hasFile('image')) {
            $post->image = $this->saveImageVersions(
                $this->imagePath,
                $request->image,
                [
                    ['name'=>'large'],
                ]
            );
            $post->update();
        }

        if ($request->hasFile('file')) {
            $post->link = $this->saveDocument(
                $this->imagePath,
                $request->file('file')
            );
            $post->update();
        }

        return redirect()->route($this->indexRoute)->withStatus(__('crud.item_has_been_added', ['item'=>$this->itemName]));
    }

    public function destroy(Posts $post)
    {
        $this->validateAccess();
        $post->delete();

        return redirect()->route($this->indexRoute)->withStatus(__('Item was deleted.'));
    }

    public function edit(Posts $post)
    {
        
        $this->validateAccess();
        $fields = $this->getFields($post);
        $itemName=$this->itemName;
        $title=$this->title;
        return view('general.form', ['setup' => [
            'title' => __('crud.edit_item_name', ['item'=>$itemName, 'name'=>$post->title]),
            'action_link' => route($this->indexRoute,['type'=>$post->post_type]),
            'action_name' => __('Back'),
            'iscontent' => true,
            'isupdate' => true,
            'action' => route($this->updateRoute, ['post' => $post->id]),
            'breadcrumbs' => [
                //[__('Landing Page'), route('admin.landing')],
                [$title, route($this->indexRoute,['type'=>$post->post_type])],
                [$post->title, null],
            ],
        ],
        'fields'=>$fields, ]);
    }

    public function update(Request $request, Posts $post)
    {
        $this->validateAccess();

        $post->title = $request->title;
        if($request->has('subtitle')){
            $post->subtitle = $request->subtitle;
        }
        if($request->has('description')){
            $post->description = $request->description;
        }


        if ($request->hasFile('image')) {
            $post->image = $this->saveImageVersions(
                $this->imagePath,
                $request->image,
                $this->getImageDimensions($post->post_type)
            );
        }

        $post->update();

        return redirect()->route($this->indexRoute,['type'=>$post->post_type])->withStatus(__('Item was updated'));
    }

    //Create show functions that returns the view and the pdf file as parameter
    public function show($post)
    {
        $post=Posts::findOrFail($post);
        return redirect('https://docs.google.com/gview?embedded=true&url='.$post->link);
    }

}